package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.RegisterParents;

/**
 * 注册-家长Mapper接口
 * 
 * @author boman
 * @date 2023-05-25
 */
public interface RegisterParentsMapper 
{
    /**
     * 查询注册-家长
     * 
     * @param id 注册-家长主键
     * @return 注册-家长
     */
    public RegisterParents selectRegisterParentsById(Long id);

    /**
     * 查询注册-家长列表
     * 
     * @param registerParents 注册-家长
     * @return 注册-家长集合
     */
    public List<RegisterParents> selectRegisterParentsList(RegisterParents registerParents);

    /**
     * 新增注册-家长
     * 
     * @param registerParents 注册-家长
     * @return 结果
     */
    public int insertRegisterParents(RegisterParents registerParents);

    /**
     * 修改注册-家长
     * 
     * @param registerParents 注册-家长
     * @return 结果
     */
    public int updateRegisterParents(RegisterParents registerParents);

    /**
     * 删除注册-家长
     * 
     * @param id 注册-家长主键
     * @return 结果
     */
    public int deleteRegisterParentsById(Long id);

    /**
     * 批量删除注册-家长
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRegisterParentsByIds(Long[] ids);

    RegisterParents selectRegisterParentsByOppenId(String oppenId);
}
