package com.ruoyi.web.controller.register;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.RegisterParents;
import com.ruoyi.system.service.IRegisterParentsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 注册-家长Controller
 * 
 * @author boman
 * @date 2023-05-25
 */
@RestController
@RequestMapping("/register/parents")
public class RegisterParentsController extends BaseController
{
    @Autowired
    private IRegisterParentsService registerParentsService;

    /**
     * 查询注册-家长列表
     */
    @PreAuthorize("@ss.hasPermi('register:parents:list')")
    @GetMapping("/list")
    public TableDataInfo list(RegisterParents registerParents)
    {
        startPage();
        List<RegisterParents> list = registerParentsService.selectRegisterParentsList(registerParents);
        return getDataTable(list);
    }

    /**
     * 导出注册-家长列表
     */
    @PreAuthorize("@ss.hasPermi('register:parents:export')")
    @Log(title = "注册-家长", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RegisterParents registerParents)
    {
        List<RegisterParents> list = registerParentsService.selectRegisterParentsList(registerParents);
        ExcelUtil<RegisterParents> util = new ExcelUtil<RegisterParents>(RegisterParents.class);
        util.exportExcel(response, list, "注册-家长数据");
    }

    /**
     * 获取注册-家长详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(registerParentsService.selectRegisterParentsById(id));
    }

    /**
     * 新增注册-家长
     */
    @Log(title = "注册-家长", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RegisterParents registerParents)
    {
        return registerParentsService.insertRegisterParents(registerParents);
    }

    /**
     * 修改注册-家长
     */
    @Log(title = "注册-家长", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody RegisterParents registerParents)
    {
        return toAjax(registerParentsService.updateRegisterParents(registerParents));
    }

    /**
     * 删除注册-家长
     */
    @PreAuthorize("@ss.hasPermi('register:parents:remove')")
    @Log(title = "注册-家长", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(registerParentsService.deleteRegisterParentsByIds(ids));
    }
}
